@@ -1,6 +1,6 @@
 """this is danil python study file"""
 
-def print_lol(the_list, level):
+def print_lol(the_list, level=0):
 #hello, this is parameter def
     for each_item in the_list:
         if isinstance(each_item, list):
